@@ -768,11 +768,10 @@ class VariableClUpdateProfileLinuxFullname(ReadonlyVariable):
             try:
                 subname = dv.Get('os_linux_subname')
                 linuxname = dv.Get('os_linux_name')
-                linuxver = dv.Get('os_linux_ver')
                 if subname:
-                    return "%s %s %s" % (linuxname, linuxver, subname)
-                return "%s %s" % (linuxname, linuxver)
-            except DataVarsError as s:
+                    return "%s %s" % (linuxname, subname)
+                return linuxname
+            except DataVarsError:
                 raise VariableError("Wrong Calculate Linux profile")
         return ""
 
